pub struct InterfaceStat {Show 14 fields
pub rx_packets: u64,
pub rx_bytes: u64,
pub rx_errors: u64,
pub rx_dropped: u64,
pub rx_overruns: u64,
pub rx_frame: u64,
pub tx_packets: u64,
pub tx_bytes: u64,
pub tx_errors: u64,
pub tx_dropped: u64,
pub tx_overruns: u64,
pub tx_collisions: u64,
pub tx_carrier: u64,
pub speed: u64,
}
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.