pub struct State {
pub name: Vec<u8>,
pub state: u8,
pub ppid: i32,
pub tty: i32,
pub priority: i32,
pub nice: i32,
pub processor: i32,
pub threads: u64,
}
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.